@@ -10,7 +10,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: class.uiconfig.inc.php,v 1.6.2.3.2.7 2005/08/26 01:33:05 skwashd Exp $ */
+  /* $Id: class.uiconfig.inc.php,v 1.6.2.3.2.8 2005/08/30 00:52:55 skwashd Exp $ */
 
 	class uiconfig
 	{
@@ -213,7 +213,7 @@
 							$configs[] = $newvals[$i];
 						}
 						$config = implode('_',$configs);
-						echo $config . '=' . $current_config[$config] . '<br />';
+						//echo $config . '=' . $current_config[$config] . '<br />';
 						if ($current_config[$config] == $setting)
 						{
 							$t->set_var($value,' selected');
