@@ -13,7 +13,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.so.inc.php,v 1.1.2.8 2005/06/21 15:07:59 ceb Exp $ */
+	/* $Id: class.so.inc.php,v 1.1.2.9 2005/12/06 13:28:40 skwashd Exp $ */
 
 	class so
 	{
@@ -121,15 +121,21 @@
 
 			if (! $values['timestamps'])
 			{
-				$values['timestamps'] = time() . ',0,0';
+				$values['timestamps'] = "{$GLOBALS['phpgw']->datetime->gmtnow},0,0";
 			}
 
 			$query = sprintf("insert into phpgw_bookmarks (bm_url, bm_name, bm_desc, bm_keywords, bm_category,"
 				. "bm_rating, bm_owner, bm_access, bm_info, bm_visits) "
 				. "values ('%s','%s','%s','%s',%s,%s,'%s','%s','%s',0)", 
-				$values['url'], addslashes($values['name']), addslashes($values['desc']), addslashes($values['keywords']),
-				$values['category'], $values['rating'], $GLOBALS['phpgw_info']['user']['account_id'], $values['access'],
-				$values['timestamps']);
+				$this->db->db_addslashes($values['url']),
+				$this->db->db_addslashes($values['name']),
+				$this->db->db_addslashes($values['desc']),
+				$this->db->db_addslashes($values['keywords']),
+				intval($values['category']),
+				intval($values['rating']),
+				$GLOBALS['phpgw_info']['user']['account_id'], 
+				$values['access'],
+				$this->db->db_addslashes($values['timestamps']));
 
 			if ($this->db->query($query,__LINE__,__FILE__))
 			{
@@ -152,16 +158,21 @@
 			$this->db->next_record();
 			$ts = explode(',',$this->db->f('bm_info'));
 	
-			$timestamps = sprintf('%s,%s,%s',$ts[0],$ts[1],time());
+			$timestamps = sprintf('%s,%s,%s', $ts[0], $ts[1], $GLOBALS['phpgw']->datetime->gmtnow);
 
 			// Update bookmark information.
 			$query = sprintf("update phpgw_bookmarks set bm_url='%s', bm_name='%s', bm_desc='%s', "
-//				. "bm_keywords='%s', bm_category='%s', bm_subcategory='%s', bm_rating='%s',"
 				. "bm_keywords='%s', bm_category=%s, bm_rating='%s',"
 				. "bm_info='%s', bm_access='%s' where bm_id='%s'", 
-					$values['url'], addslashes($values['name']), addslashes($values['desc']), addslashes($values['keywords']), 
-//					$category, $subcategory, $values['rating'], $timestamps, $values['access'], $id);
-					$values['category'],$values['rating'], $timestamps, $values['access'], intval($id));
+					$this->db->db_addslashes($values['url']), 
+					$this->db->db_addslashes($values['name']), 
+					$this->db->db_addslashes($values['desc']),
+					$this->db->db_addslashes($values['keywords']), 
+					intval($values['category']),
+					intval($values['rating']),
+					$this->db->db_addslashes($timestamps),
+					$values['access'], 
+					intval($id));
 
 			if ($this->db->query($query,__LINE__,__FILE__))
 			{
@@ -176,8 +187,8 @@
 		function updatetimestamp($id,$timestamp)
 		{
 			$query = 'UPDATE phpgw_bookmarks'
-				. ' SET bm_info=' . intval($timestamp) 
-				. ' , bm_visits=bm_visits+1 WHERE bm_id=' .intval($id);
+				. " SET bm_info='" . $this->db->db_addslashes($timestamp) . "', "
+				. 'bm_visits = (bm_visits + 1) WHERE bm_id=' .intval($id);
 			$this->db->query($query,__LINE__,__FILE__);
 		}
 
