@@ -8,13 +8,12 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: hook_deleteaccount.inc.php,v 1.1.2.1 2002/11/20 19:54:03 ralfbecker Exp $ */
+	/* $Id: hook_deleteaccount.inc.php,v 1.1.2.1.2.1 2005/12/04 04:45:02 skwashd Exp $ */
 
 	// Delete all records for a user
 	$info = CreateObject('infolog.soinfolog');
 
-	$info->change_delete_owner(intval($GLOBALS['HTTP_POST_VARS']['account_id']),
-		intval($GLOBALS['HTTP_POST_VARS']['new_owner']));
+	$info->change_delete_owner(intval($_POST['account_id']), intval($_POST['new_owner']));
 
 	unset($info);
 ?>
