@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	// $Id: tables_update.inc.php,v 1.53.2.9.2.41 2005/08/26 01:40:22 skwashd Exp $
+	// $Id: tables_update.inc.php,v 1.53.2.9.2.44 2005/12/18 08:25:39 skwashd Exp $
 	// $Source: /cvsroot/phpgwapi/phpgwapi/setup/tables_update.inc.php,v $
 
 	/* Include older phpGroupWare update support */
@@ -673,7 +673,7 @@
 				{
 					if (!empty($app) && count($pref))
 					{
-						$app = addslashes($app);
+						$app = $GLOBALS['phpgw_setup']->db->db_addslashes($app);
 						$pref = serialize($pref);
 						$db2->query("INSERT INTO phpgw_preferences".
 							" (preference_owner,preference_app,preference_value)".
@@ -1795,5 +1795,17 @@
 	function phpgwapi_upgrade0_9_16_007()
 	{
 		return $GLOBALS['phpgw_info']['phpgwapi']['currentver'] = '0.9.16.008';
-	}		
+	}
+
+	$test[] = '0.9.16.008';
+	function phpgwapi_upgrade0_9_16_008()
+	{
+		return $GLOBALS['phpgw_info']['phpgwapi']['currentver'] = '0.9.16.009';
+	}
+
+	$test[] = '0.9.16.009';
+	function phpgwapi_upgrade0_9_16_009()
+	{
+		return $GLOBALS['phpgw_info']['phpgwapi']['currentver'] = '0.9.16.010';
+	}
 ?>
