@@ -9,9 +9,10 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: applications.php,v 1.21.2.13 2004/11/06 16:13:46 powerstat Exp $ */
+  /* $Id: applications.php,v 1.21.2.15 2005/12/04 10:17:34 skwashd Exp $ */
 
 	$DEBUG = $_POST['debug'] || $_GET['debug'];
+
 	/*
 	 TODO: We allow a user to hose their setup here, need to make use
 	 of dependencies so they are warned that they are pulling the rug
@@ -32,10 +33,16 @@
 	// Check header and authentication
 	if (!$GLOBALS['phpgw_setup']->auth('Config'))
 	{
+		// Does not return unless user is authorized
 		Header('Location: index.php');
 		exit;
 	}
-	// Does not return unless user is authorized
+	
+	if( isset($_POST['cancel']) && $_POST['cancel'] )
+	{
+		Header("Location: index.php");
+		exit;
+	}
 
 	$ConfigDomain = get_var('ConfigDomain',Array('POST','COOKIE'));
 
@@ -108,12 +115,6 @@
 	//var_dump($setup_info);exit;
 	@ksort($setup_info);
 
-	if(@get_var('cancel',Array('POST')))
-	{
-		Header("Location: index.php");
-		exit;
-	}
-
 	if(@get_var('submit',Array('POST')))
 	{
 		$GLOBALS['phpgw_setup']->html->show_header(lang('Application Management'),False,'config',$ConfigDomain . '(' . $phpgw_domain[$ConfigDomain]['db_type'] . ')');
