@@ -14,7 +14,7 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: class.ui.inc.php,v 1.2.2.14.2.3 2004/03/09 21:34:10 gugux Exp $ */
+	/* $Id: class.ui.inc.php,v 1.2.2.14.2.5 2005/12/07 11:51:23 skwashd Exp $ */
 
 	class ui
 	{
@@ -199,7 +199,7 @@
 					$title = "$words[0] $words[1] $words[2] $words[3] ...";
 				}
 
-				if ($level == 0)
+				if ($level <= 0)
 				{
 					$title = '<font color="#0000EE"><b>' . $title . '</b></font>';
 				}
@@ -541,7 +541,7 @@
 			$this->t->set_var('lang_access',lang('Access'));
 			$this->t->set_var('access',lang($values['access']));
 
-			$this->t->set_var('history',$this->historylog->return_html(array(),'','',$GLOBALS['todo_id']));
+			$this->t->set_var('history',$this->historylog->return_html(array(),'','', $todo_id));
 			$this->t->set_var('done_action',$GLOBALS['phpgw']->link('/index.php','menuaction=todo.ui.show_list&cat_id=' . $values['cat']));
 			$this->t->pfp('out','_view');
 		}
